pub trait Readable { }Expand description
Trait implemented by access modes that allow reading.
This is used as a generic bound on Register::read to prevent compile-time
errors when attempting to read from write-only registers.
pub trait Readable { }Trait implemented by access modes that allow reading.
This is used as a generic bound on Register::read to prevent compile-time
errors when attempting to read from write-only registers.