pub trait Writable { }Expand description
Trait implemented by access modes that allow writing.
This is used as a generic bound on Register::write to prevent compile-time
errors when attempting to write to read-only registers.
pub trait Writable { }Trait implemented by access modes that allow writing.
This is used as a generic bound on Register::write to prevent compile-time
errors when attempting to write to read-only registers.